.. _label_density:

===============
Density modules
===============

.. automodule:: maicos.modules.density

Density planar
==============

.. automodule:: maicos.modules.density.DensityPlanar
    :members:
    :undoc-members:
    :show-inheritance:

Density cylinder
================

.. automodule:: maicos.modules.density.DensityCylinder
    :members:
    :undoc-members:
    :show-inheritance:
